summaryrefslogtreecommitdiff
path: root/init2.c
diff options
context:
space:
mode:
authorpelissip <pelissip@280ebfd0-de03-0410-8827-d642c229c3f4>2004-04-07 14:40:47 +0000
committerpelissip <pelissip@280ebfd0-de03-0410-8827-d642c229c3f4>2004-04-07 14:40:47 +0000
commit2bc26fb8ca6e4e783f0ecc1a01430815bf9c50b2 (patch)
tree0f024e6c674a1f626e5a8231e7cda2d08e7ab120 /init2.c
parentc44bde008cebc99a76205f1329ac86fef8cf65c3 (diff)
downloadmpfr-2bc26fb8ca6e4e783f0ecc1a01430815bf9c50b2.tar.gz
Modify a few the allocation scheme without gmp-impl.h
Add pseudo-constants __MPFR_EXP_NAN, __MPFR_EXP_ZERO and __MPFR_EXP_INF for future (?) inlining of some functions. git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@2863 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'init2.c')
-rw-r--r--init2.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/init2.c b/init2.c
index 3c44e532c..6369f7396 100644
--- a/init2.c
+++ b/init2.c
@@ -37,8 +37,10 @@ mpfr_init2 (mpfr_ptr x, mp_prec_t p)
MPFR_ASSERTN( BITS_PER_MP_LIMB == BYTES_PER_MP_LIMB * CHAR_BIT
&& sizeof(mp_limb_t) == BYTES_PER_MP_LIMB );
- /* Check for correct EXP NAN in both mpfr.h and in mpfr-impl.h */
- MPFR_ASSERTN( __MPFR_EXP_NAN == MPFR_EXP_NAN );
+ /* Check for correct EXP NAN, ZERO & INF in both mpfr.h and in mpfr-impl.h */
+ MPFR_ASSERTN( __MPFR_EXP_NAN == MPFR_EXP_NAN );
+ MPFR_ASSERTN( __MPFR_EXP_ZERO == MPFR_EXP_ZERO );
+ MPFR_ASSERTN( __MPFR_EXP_INF == MPFR_EXP_INF );
/* p=1 is not allowed since the rounding to nearest even rule requires at
least two bits of mantissa: the neighbours of 3/2 are 1*2^0 and 1*2^1,